aboutsummaryrefslogtreecommitdiff
path: root/examples/graph_resnet50.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'examples/graph_resnet50.cpp')
-rw-r--r--examples/graph_resnet50.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/examples/graph_resnet50.cpp b/examples/graph_resnet50.cpp
index 0ad719a2ca..4221d98048 100644
--- a/examples/graph_resnet50.cpp
+++ b/examples/graph_resnet50.cpp
@@ -31,16 +31,16 @@ using namespace arm_compute::utils;
using namespace arm_compute::graph::frontend;
using namespace arm_compute::graph_utils;
/** Example demonstrating how to implement ResNet50 network using the Compute Library's graph API
*
* @param[in] argc Number of arguments
* @param[in] argv Arguments
*/
-class GraphResNet50Example : public Example
+class GraphResNetV1_50Example : public Example
{
public:
- GraphResNet50Example()
- : cmd_parser(), common_opts(cmd_parser), common_params(), graph(0, "ResNet50")
+ GraphResNetV1_50Example()
+ : cmd_parser(), common_opts(cmd_parser), common_params(), graph(0, "ResNetV1_50")
{
}
bool do_setup(int argc, char **argv) override
@@ -237,7 +237,7 @@ private:
}
};
/** Main program for ResNet50
*
* @note To list all the possible arguments execute the binary appended with the --help option
*
@@ -246,5 +246,5 @@ private:
*/
int main(int argc, char **argv)
{
- return arm_compute::utils::run_example<GraphResNet50Example>(argc, argv);
+ return arm_compute::utils::run_example<GraphResNetV1_50Example>(argc, argv);
}
@@ -31,16 +31,16 @@ using namespace arm_compute::utils;
using namespace arm_compute::graph::frontend;
using namespace arm_compute::graph_utils;
-/** Example demonstrating how to implement ResNet50 network using the Compute Library's graph API
+/** Example demonstrating how to implement ResNetV1_50 network using the Compute Library's graph API
*
* @param[in] argc Number of arguments
@@ -237,7 +237,7 @@ private:
}
};
-/** Main program for ResNet50
+/** Main program for ResNetV1_50
*
* @note To list all the possible arguments execute the binary appended with the --help option